************************************
The sherpa.plot.backend_utils module
************************************

.. currentmodule:: sherpa.plot.backend_utils

.. automodule:: sherpa.plot.backend_utils

   .. rubric:: Functions

   .. autosummary::
      :toctree: api

      translate_args
      add_kwargs_to_doc
      get_keyword_defaults
